@@ -50,14 +50,14 @@ function(x, y) {
 		
 	int  <- gIntersection(x[subsx,], y[subsy,], byid=TRUE)
 	if (inherits(int, "SpatialCollections")) {
-		if (is.null(int@polyobj)) { # ??
-			warning('polygons do not intersect')
+		if (is.null(int@polyobj)) { # merely touching, no intersection
+			#warning('polygons do not intersect')
 			return(NULL)
 		}
 		int <- int@polyobj
 	}
 	if (!inherits(int, 'SpatialPolygons')) {
-		warning('polygons do not intersect')
+		# warning('polygons do not intersect')
 		return(NULL)
 	}
 
