@@ -11,7 +11,7 @@
 	scale <- xres(x)
 	if (isTRUE(all.equal(xmin(x), -180, tolerance=tolerance, scale=scale)) & 
 		isTRUE(all.equal(xmax(x),  180, tolerance=tolerance, scale=scale))) {
-		if (.couldBeLonLat(x)) {
+		if (.couldBeLonLat(x, warnings=FALSE)) {
  			res <- TRUE
 		}
 	}
