@@ -6,7 +6,7 @@
 
 .stackCDF <- function(filename, varname='', bands='') {
 
-	ncdf4 <- raster:::.NCDFversion4()
+	ncdf4 <- .NCDFversion4()
 
 	if (ncdf4) {
 		nc <- ncdf4::nc_open(filename)
@@ -17,7 +17,7 @@
 		on.exit( close.ncdf(nc) )		
 	} 
 
-	zvar <- raster:::.varName(nc, varname)
+	zvar <- .varName(nc, varname)
 	dims <- nc$var[[zvar]]$ndims	
 	
 	dim3 <- 3
@@ -41,7 +41,7 @@
 			st@z <- list( nc$var[[zvar]]$dim[[dim3]]$vals[bands] )
 			names(st@z) <- nc$var[[zvar]]$dim[[dim3]]$units
 			if ( nc$var[[zvar]]$dim[[dim3]]$name == 'time' ) {	
-				try( st <- raster:::.doTime(st, nc, zvar, dim3, ncdf4)  )
+				try( st <- .doTime(st, nc, zvar, dim3, ncdf4)  )
 			}
 			nms <- as.character(st@z[[1]])
 			st@layers <- lapply(bands, function(x){
