@@ -17,6 +17,9 @@
 	cells <- cells[order(cells[,2]), ,drop=FALSE]
 	uniquecells <- sort(na.omit(unique(cells[,2])))
 	uniquecells <- uniquecells[(uniquecells > 0) & (uniquecells <= ncell(x))]
+	if (length(uniquecells) == 0) {
+		return( matrix(NA, nrow=nrow(cells), ncol=length(layers)) )
+	}
 
 	adjust <- TRUE
 	if (length(uniquecells) > 0) {
